Learn R Programming

fractalforest (version 1.0.1)

is_branch_symbol: Check if character is a branch symbol

Description

Check if character is a branch symbol

Usage

is_branch_symbol(x)

Value

A logical vector the same length as x, with TRUE for elements that are not one of the branch symbols ("[", "]", "+", "-", "(", ")", "<", ">"), and FALSE otherwise.

Arguments

x

an R object to be tested.