Learn R Programming

fractalforest (version 1.0.1)

is_pop_symbol: Check if character is a pop symbol

Description

Check if character is a pop symbol

Usage

is_pop_symbol(x)

Value

A logical vector the same length as x, with TRUE for elements equal to the pop symbol "]", and FALSE otherwise.

Arguments

x

an R object to be tested.