powered by
Check if character is a pop symbol
is_pop_symbol(x)
A logical vector the same length as x, with TRUE for elements equal to the pop symbol "]", and FALSE otherwise.
x
TRUE
"]"
FALSE
an R object to be tested.